function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }
function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }
/*
 * Choice JS
*/

class Builder {
  /* ------------------------------------------------------------------------------------------------------------------------------------------------
  |  HTML Builders
  ------------------------------------------------------------------------------------------------------------------------------------------------ */

  /* ------------------------------------------------------------------------------------------------------------------------------------------------
  |  Bindings
  ------------------------------------------------------------------------------------------------------------------------------------------------ */

  /**
   * Bind option filtering. When a user types into the search box
   *
   * @param {HTMLElement} choice - The choice we're binding
   * @return {Promise}
  */
  bindOptionFiltering(choice) {
    var _this = this;
    return _asyncToGenerator(function* () {
      //If we have a dynamic url, do not bind to the list
      if (_this.target.hasAttribute('data-choice-search-url')) return;
      //When the choice search bar changes
      var searchTimeout = 0,
        searchBar = _this.dropdown.querySelector('.choicejs-search'),
        options = _this.dropdown.querySelectorAll('ul li');
      //When the postcode is changed, test it
      searchBar.addEventListener('input', () => {
        //Clear the above timeout
        clearTimeout(searchTimeout);
        //Set a new timeout
        searchTimeout = setTimeout(() => {
          //Loop all options
          for (var option of options) {
            if (option.innerHTML.toLowerCase().includes(searchBar.value.toLowerCase())) {
              option.classList.remove('hide');
            } else {
              option.classList.add('hide');
            }
          }
        }, 500);
      });
      //Return
      return;
    })();
  }

  /**
   * Bind dynamic search if the user has provided an endpoint to use
   *
   * @param {HTMLElement} choice - The choice we're binding
   * @return {Promise}
  */
  bindDynamicSearch(choice) {
    var _this2 = this;
    return _asyncToGenerator(function* () {
      //Has the user also asked for multiple? If yes, warn and quit
      var multiple = _this2.target.hasAttribute('multiple') && ['true', 'multiple'].includes(_this2.target.getAttribute('multiple'));
      if (multiple) {
        console.info("Choice JS - Multiple options is not supported with live searching.");
        return;
      }
      //Get the url endpoint if we have one
      if (_this2.target.hasAttribute('data-choice-search-url')) {
        //Get the endpoint we're using
        var endpoint = _this2.target.getAttribute('data-choice-search-url'),
          searchBar = _this2.dropdown.querySelector('.choicejs-search'),
          choiceList = _this2.dropdown.querySelector('ul');
        //Watch for the search change
        var searchTimeout = 0;
        //Remove the bindings to avoid duplicates
        searchBar.addEventListener('keyup', _listener => {
          //Try
          try {
            clearTimeout(searchTimeout);
            //Set timeout
            searchTimeout = setTimeout( /*#__PURE__*/_asyncToGenerator(function* () {
              //Clear the select options and the choice options
              choiceList.innerHTML = '';
              _this2.target.innerHTML = '';
              //Get the user input, allow empty so the user can check in backend if empty and return default set
              var userInput = searchBar.value;
              //Build our params
              var url = new URL(endpoint);
              url.search = new URLSearchParams({
                choicesearch: userInput
              }).toString();
              //Run the search
              var response = yield fetch(url),
                result = yield response.json();
              for (var option of result) {
                //Create a new item
                var choiceItem = document.createElement('li'),
                  selectItem = document.createElement('option');
                //Set the visible value
                choiceItem.innerHTML = option.label;
                selectItem.innerHTML = option.label;
                //Set the actual value
                choiceItem.setAttribute('value', option.value);
                selectItem.value = option.value;
                //Append it to choice
                choiceList.appendChild(choiceItem);
                //Append it to our select
                _this2.target.appendChild(selectItem);
              }
              //Re-run our choice bindings
              _this2.bindOptionSelect(choice);
            }), 1000);
          } catch (e) {
            console.log('ChoiceJS error fetching endpoint', e);
          }
        });
      }
      //Return
      return;
    })();
  }
}