/*
 * Choice JS
*/

class Builder {




    /* ------------------------------------------------------------------------------------------------------------------------------------------------
    |  HTML Builders
    ------------------------------------------------------------------------------------------------------------------------------------------------ */




    /* ------------------------------------------------------------------------------------------------------------------------------------------------
    |  Bindings
    ------------------------------------------------------------------------------------------------------------------------------------------------ */


    /**
     * Bind option filtering. When a user types into the search box
     *
     * @param {HTMLElement} choice - The choice we're binding
     * @return {Promise}
    */
    async bindOptionFiltering(choice){
        //If we have a dynamic url, do not bind to the list
        if(this.target.hasAttribute('data-choice-search-url')) return;
        //When the choice search bar changes
        var searchTimeout = 0,
            searchBar = this.dropdown.querySelector('.choicejs-search'),
            options = this.dropdown.querySelectorAll('ul li');
        //When the postcode is changed, test it
        searchBar.addEventListener('input', () => {
            //Clear the above timeout
            clearTimeout(searchTimeout);
            //Set a new timeout
            searchTimeout = setTimeout(() =>{
                //Loop all options
                for(let option of options){
                    if(option.innerHTML.toLowerCase().includes(searchBar.value.toLowerCase())){
                        option.classList.remove('hide');
                    } else {
                        option.classList.add('hide');
                    }
                }
            }, 500);
        });
        //Return
        return;
    }


    /**
     * Bind dynamic search if the user has provided an endpoint to use
     *
     * @param {HTMLElement} choice - The choice we're binding
     * @return {Promise}
    */
    async bindDynamicSearch(choice){
        //Has the user also asked for multiple? If yes, warn and quit
        let multiple = (this.target.hasAttribute('multiple') && ['true', 'multiple'].includes(this.target.getAttribute('multiple')));
        if(multiple){
            console.info("Choice JS - Multiple options is not supported with live searching.");
            return;
        }
        //Get the url endpoint if we have one
        if(this.target.hasAttribute('data-choice-search-url')){
            //Get the endpoint we're using
            let endpoint = this.target.getAttribute('data-choice-search-url'),

                searchBar = this.dropdown.querySelector('.choicejs-search'),
                choiceList = this.dropdown.querySelector('ul');
            //Watch for the search change
            let searchTimeout = 0;
            //Remove the bindings to avoid duplicates
            searchBar.addEventListener('keyup', _listener => {
                //Try
                try {
                    clearTimeout(searchTimeout);
                    //Set timeout
                    searchTimeout = setTimeout(async () => {
                        //Clear the select options and the choice options
                        choiceList.innerHTML = '';
                        this.target.innerHTML = '';
                        //Get the user input, allow empty so the user can check in backend if empty and return default set
                        let userInput = searchBar.value;
                        //Build our params
                        let url = new URL(endpoint)
                        url.search = new URLSearchParams({choicesearch: userInput}).toString();
                        //Run the search
                        let response = await fetch(url),
                            result = await response.json();
                        for(let option of result){
                            //Create a new item
                            let choiceItem = document.createElement('li'),
                                selectItem = document.createElement('option');
                            //Set the visible value
                            choiceItem.innerHTML = option.label;
                            selectItem.innerHTML = option.label;
                            //Set the actual value
                            choiceItem.setAttribute('value', option.value);
                            selectItem.value = option.value;
                            //Append it to choice
                            choiceList.appendChild(choiceItem);
                            //Append it to our select
                            this.target.appendChild(selectItem);
                        }
                        //Re-run our choice bindings
                        this.bindOptionSelect(choice);
                    }, 1000);
                } catch(e){
                    console.log('ChoiceJS error fetching endpoint', e);
                }
            })
        }
        //Return
        return;
    }


}